# image-tools

[![Actions Status](https://github.com/mapilio/manipulator/workflows/CI/badge.svg)](https://github.com/mapilio/imagery/actions)


## Git clone 
    git clone https://github.com/mapilio/imagery.git
## Installation
One possibility is to install with pip:

    pip install git@github.com:mapilio/imagery.git
Install with setup.py:


    cd imagery
    python setup.py install --force
##### or
    cd imagery
    pip install -e .
